@@ -8,7 +8,7 @@ These settings act as the default (base) settings for the Sentry-provided web-se
 :license: BSD, see LICENSE for more details.
 """
 
-from django.conf.global_settings import *
+from django.conf.global_settings import *  # NOQA
 
 import hashlib
 import os
@@ -17,7 +17,7 @@ import socket
 import sys
 import urlparse
 
-DEBUG = False
+DEBUG = True
 TEMPLATE_DEBUG = True
 
 ADMINS = ()
@@ -137,10 +137,12 @@ INSTALLED_APPS = (
     'django.contrib.auth',
     'django.contrib.admin',
     'django.contrib.contenttypes',
+    'django.contrib.messages',
     'django.contrib.sessions',
     'django.contrib.sites',
-    'django.contrib.messages',
+    'django.contrib.staticfiles',
 
+    'compressor',
     'crispy_forms',
     'djcelery',
     'gunicorn',
@@ -157,7 +159,32 @@ INSTALLED_APPS = (
     'django_social_auth_trello',
 )
 
-STATIC_URL = '/_admin_media/'
+STATIC_ROOT = os.path.join(PROJECT_ROOT, 'static')
+STATIC_URL = '/_static/'
+
+NPM_ROOT = os.path.abspath(os.path.join(PROJECT_ROOT, os.pardir, os.pardir, 'node_modules'))
+if os.path.exists(NPM_ROOT):
+    LESS_BIN = os.path.join(NPM_ROOT, 'less', 'bin', 'lessc')
+else:
+    LESS_BIN = None
+
+# XXX: There is a bug in django-compressor that causes it to incorrectly handle
+# relative URLs in precompiled files (less) when compression is disabled
+if LESS_BIN:
+    COMPRESS_ENABLED = True
+    COMPRESS_URL = STATIC_URL
+    COMPRESS_OUTPUT_DIR = 'CACHE'
+    COMPRESS_PRECOMPILERS = (
+        ('text/less', '%s --strict-imports {infile} {outfile}' % (LESS_BIN,)),
+    )
+else:
+    COMPRESS_ENABLED = False
+
+STATICFILES_FINDERS = (
+    "django.contrib.staticfiles.finders.FileSystemFinder",
+    "django.contrib.staticfiles.finders.AppDirectoriesFinder",
+    "compressor.finders.CompressorFinder",
+)
 
 LOCALE_PATHS = (
     os.path.join(PROJECT_ROOT, 'locale'),
@@ -244,28 +271,38 @@ EMAIL_SUBJECT_PREFIX = '[Sentry] '
 # Disable South in tests as it is sending incorrect create signals
 SOUTH_TESTS_MIGRATE = False
 
-# Configure logging
-from raven.conf import setup_logging
-from raven.contrib.django.handlers import SentryHandler
-import logging
-
-# Configure root logger
-logger = logging.getLogger()
-logger.setLevel(logging.INFO)
-
-handler = logging.StreamHandler()
-handler.setLevel(logging.INFO)
-logger.addHandler(handler)
-
-# Disable django.request as it's generally useless
-logger = logging.getLogger('django.request')
-logger.propagate = False
-logger.addHandler(handler)
-
-# Configure default sentry logging
-sentry_handler = SentryHandler()
-sentry_handler.setLevel(logging.ERROR)
-setup_logging(sentry_handler)
+LOGGING = {
+    'version': 1,
+    'disable_existing_loggers': True,
+    'handlers': {
+        'console': {
+            'level': 'WARNING',
+            'class': 'logging.StreamHandler'
+        },
+        'sentry': {
+            'class': 'raven.contrib.django.handlers.SentryHandler',
+        }
+    },
+    'loggers': {
+        '()': {
+            'handlers': ['console', 'sentry'],
+            'propagate': True,
+        },
+        'root': {
+            'handlers': ['console', 'sentry'],
+        },
+        'sentry.errors': {
+            'level': 'ERROR',
+            'handlers': ['console', 'sentry'],
+            'propagate': False,
+        },
+        'django.request': {
+            'level': 'ERROR',
+            'handlers': ['console'],
+            'propagate': False,
+        },
+    }
+}
 
 # Configure celery
 import djcelery
