@@ -80,6 +80,9 @@ class Interface(object):
     def serialize(self):
         return dict((k, self.__dict__[k]) for k in self.attrs)
 
+    def get_composite_hash(self, interfaces):
+        return self.get_hash()
+
     def get_hash(self):
         return []
 
@@ -262,13 +265,19 @@ class Stacktrace(Interface):
             return value
         elif not value:
             return value
-        return value[:100]
+        return value
 
     def serialize(self):
         return {
             'frames': self.frames,
         }
 
+    def get_composite_hash(self, interfaces):
+        output = self.get_hash()
+        if 'sentry.interfaces.Exception' in interfaces:
+            output.append(interfaces['sentry.interfaces.Exception'].type)
+        return output
+
     def get_hash(self):
         output = []
         for frame in self.frames:
@@ -277,13 +286,16 @@ class Stacktrace(Interface):
             else:
                 output.append(frame['filename'])
 
-            if frame.get('function'):
+            if frame.get('context_line'):
+                output.append(frame['context_line'])
+            elif frame.get('function'):
                 output.append(frame['function'])
             elif frame.get('lineno'):
                 output.append(frame['lineno'])
         return output
 
     def to_html(self, event):
+        system_frames = 0
         frames = []
         for frame in self.frames:
             if frame.get('context_line') and frame.get('lineno') is not None:
@@ -304,6 +316,8 @@ class Stacktrace(Interface):
             else:
                 lineno = None
 
+            in_app = bool(frame.get('in_app', True))
+
             frames.append({
                 'abs_path': frame.get('abs_path'),
                 'filename': frame['filename'],
@@ -312,8 +326,15 @@ class Stacktrace(Interface):
                 'lineno': lineno,
                 'context': context,
                 'vars': context_vars,
+                'in_app': in_app,
             })
 
+            if not in_app:
+                system_frames += 1
+
+        if len(frames) == system_frames:
+            system_frames = 0
+
         if env.request and env.request.user.is_authenticated():
             display = UserOption.objects.get_value(
                 user=env.request.user,
@@ -325,6 +346,7 @@ class Stacktrace(Interface):
                 frames.reverse()
 
         return render_to_string('sentry/partial/interfaces/stacktrace.html', {
+            'system_frames': system_frames,
             'event': event,
             'frames': frames,
             'stacktrace': self.get_traceback(event),
@@ -338,10 +360,13 @@ class Stacktrace(Interface):
             'Stacktrace (most recent call last):', '',
         ]
         for frame in self.frames:
+            pieces = ['  File "%(filename)s"']
+            if 'lineno' in frame:
+                pieces.append(', line %(lineno)s')
             if 'function' in frame:
-                result.append('  File "%(filename)s", line %(lineno)s, in %(function)s' % frame)
-            else:
-                result.append('  File "%(filename)s", line %(lineno)s' % frame)
+                pieces.append(', in %(function)s')
+
+            result.append(''.join(pieces) % frame)
             if 'context_line' in frame:
                 result.append('    %s' % frame['context_line'].strip())
 
@@ -392,10 +417,7 @@ class Exception(Interface):
         }
 
     def get_hash(self):
-        output = filter(bool, [self.module, self.type])
-        if not output:
-            output = [self.value]
-        return output
+        return filter(bool, [self.type, self.value])
 
     def to_html(self, event):
         last_frame = None
