@@ -17,7 +17,7 @@ from django.utils.translation import ugettext as _
 from paging.helpers import paginate as paginate_func
 from sentry.conf import settings
 from sentry.models import Group
-from sentry.utils import json
+from sentry.utils.javascript import to_json
 from sentry.utils.strings import truncatechars
 from templatetag_sugar.register import tag
 from templatetag_sugar.parser import Name, Variable, Constant, Optional
@@ -31,6 +31,8 @@ register = template.Library()
 truncatechars = register.filter(stringfilter(truncatechars))
 truncatechars.is_safe = True
 
+to_json = register.filter(to_json)
+
 
 @register.filter
 def pprint(value, break_after=10):
@@ -96,11 +98,6 @@ def num_digits(value):
     return len(str(value))
 
 
-@register.filter
-def to_json(data):
-    return json.dumps(data)
-
-
 @register.filter
 def to_str(data):
     return str(data)
