@@ -8,27 +8,30 @@ sentry.web.views
 import datetime
 import logging
 
+from django.contrib.auth.models import AnonymousUser
 from django.core.urlresolvers import reverse
-from django.http import HttpResponse, HttpResponseBadRequest, \
+from django.db.models import Sum
+from django.http import HttpResponse, \
   HttpResponseForbidden, HttpResponseRedirect
 from django.utils import timezone
 from django.views.decorators.cache import never_cache
 from django.views.decorators.csrf import csrf_exempt
-from django.views.decorators.http import require_http_methods
 from django.views.decorators.vary import vary_on_cookie
-from functools import wraps
+from django.views.generic.base import View as BaseView
 from sentry.conf import settings
 from sentry.constants import MEMBER_USER
-from sentry.coreapi import project_from_auth_vars, project_from_id, \
+from sentry.coreapi import project_from_auth_vars, \
   decode_and_decompress_data, safely_load_json_string, validate_data, \
-  insert_data_to_database, APIError, APIUnauthorized, extract_auth_vars
+  insert_data_to_database, APIError, APIForbidden, extract_auth_vars
 from sentry.exceptions import InvalidData
-from sentry.models import Group, GroupBookmark, Project, View, FilterValue
+from sentry.models import Group, GroupBookmark, Project, ProjectCountByMinute, FilterValue
+from sentry.plugins import plugins
 from sentry.templatetags.sentry_helpers import with_metadata
 from sentry.utils import json
 from sentry.utils.cache import cache
 from sentry.utils.db import has_trending
-from sentry.utils.http import is_same_domain, is_valid_origin, apply_access_control_headers
+from sentry.utils.javascript import to_json
+from sentry.utils.http import is_valid_origin, get_origins
 from sentry.web.decorators import has_access
 from sentry.web.frontend.groups import _get_group_list
 from sentry.web.helpers import render_to_response, render_to_string, get_project_list
@@ -58,37 +61,146 @@ def transform_groups(request, group_list, template='sentry/partial/_group.html')
     ]
 
 
-def api_method(func):
-    @wraps(func)
-    @csrf_exempt
-    def wrapped(request, project_id=None, *args, **kwargs):
+class Auth(object):
+    def __init__(self, auth_vars):
+        self.client = auth_vars.get('sentry_client')
+        self.version = auth_vars.get('sentry_version')
+        self.secret_key = auth_vars.get('sentry_secret')
+        self.public_key = auth_vars.get('sentry_key')
+
+
+class APIView(BaseView):
+    def _get_project_from_id(self, project_id):
         if project_id:
             if project_id.isdigit():
                 lookup_kwargs = {'id': int(project_id)}
             else:
                 lookup_kwargs = {'slug': project_id}
+
             try:
-                project = Project.objects.get_from_cache(**lookup_kwargs)
+                return Project.objects.get_from_cache(**lookup_kwargs)
             except Project.DoesNotExist:
-                return HttpResponse('Invalid project_id: %r' % project_id, status=400)
-        else:
-            project = None
+                raise APIError('Invalid project_id: %r' % project_id)
+        return None
 
+    def _parse_header(self, request, project):
+        try:
+            auth_vars = extract_auth_vars(request)
+        except (IndexError, ValueError):
+            raise APIError('Invalid auth header')
+
+        if not auth_vars:
+            raise APIError('Client/server version mismatch: Unsupported client')
+
+        server_version = auth_vars.get('sentry_version', '1.0')
+        client = auth_vars.get('sentry_client', request.META.get('HTTP_USER_AGENT'))
+
+        if server_version not in ('2.0', '3'):
+            raise APIError('Client/server version mismatch: Unsupported protocol version (%s)' % server_version)
+
+        if not client:
+            raise APIError('Client request error: Missing client version identifier')
+
+        return auth_vars
+
+    @csrf_exempt
+    def dispatch(self, request, project_id=None, *args, **kwargs):
         origin = request.META.get('HTTP_ORIGIN', None)
-        if origin is not None and not is_valid_origin(origin, project):
-            return HttpResponse('Invalid origin: %r' % origin, status=400)
 
-        response = func(request, project, *args, **kwargs)
-        response = apply_access_control_headers(response, origin)
+        response = self._dispatch(request, project_id=project_id, *args, **kwargs)
+
+        if response.status_code != 200:
+            # Set X-Sentry-Error as in many cases it is easier to inspect the headers
+            response['X-Sentry-Error'] = response.content[:200]  # safety net on content length
+
+            if origin:
+                # We allow all origins on errors
+                response['Access-Control-Allow-Origin'] = '*'
+
+        if origin:
+            response['Access-Control-Allow-Headers'] = 'X-Sentry-Auth, X-Requested-With, Origin, Accept, Content-Type, ' \
+                'Authentication'
+            response['Access-Control-Allow-Methods'] = ', '.join(self._allowed_methods())
 
         return response
-    return wrapped
+
+    def _dispatch(self, request, project_id=None, *args, **kwargs):
+        request.user = AnonymousUser()
+
+        try:
+            project = self._get_project_from_id(project_id)
+        except APIError, e:
+            return HttpResponse(str(e), status=400)
+
+        origin = request.META.get('HTTP_ORIGIN', None)
+        if origin is not None:
+            if not project:
+                return HttpResponse('Your client must be upgraded for CORS support.')
+            elif not is_valid_origin(origin, project):
+                return HttpResponse('Invalid origin: %r' % origin, status=400)
+
+        # XXX: It seems that the OPTIONS call does not always include custom headers
+        if request.method == 'OPTIONS':
+            response = self.options(request, project)
+        else:
+            try:
+                auth_vars = self._parse_header(request, project)
+            except APIError, e:
+                return HttpResponse(str(e), status=400)
+
+            try:
+                project_, user = project_from_auth_vars(auth_vars)
+            except APIError, error:
+                if project:
+                    logger.info('Project %r raised API error: %s', project.slug, error, extra={
+                        'request': request,
+                    }, exc_info=True)
+                return HttpResponse(unicode(error.msg), status=error.http_status)
+            else:
+                if user:
+                    request.user = user
+
+            # Legacy API was /api/store/ and the project ID was only available elsewhere
+            if not project:
+                if not project_:
+                    return HttpResponse('Unable to identify project', status=400)
+                project = project_
+            elif project_ != project:
+                return HttpResponse('Project ID mismatch', status=400)
+
+            auth = Auth(auth_vars)
+
+            if auth.version == '3':
+                # Version 3 enforces secret key for server side requests
+                if origin is None and not auth.secret_key:
+                    return HttpResponse('Missing required attribute in authentication header: sentry_secret', status=400)
+
+            try:
+                response = super(APIView, self).dispatch(request, project=project, auth=auth, **kwargs)
+
+            except APIError, error:
+                logger.info('Project %r raised API error: %s', project.slug, error, extra={
+                    'request': request,
+                }, exc_info=True)
+                response = HttpResponse(unicode(error.msg), status=error.http_status)
+
+        if origin:
+            response['Access-Control-Allow-Origin'] = origin
+
+        return response
+
+    # XXX: backported from Django 1.5
+    def _allowed_methods(self):
+        return [m.upper() for m in self.http_method_names if hasattr(self, m)]
+
+    def options(self, request, *args, **kwargs):
+        response = HttpResponse()
+        response['Allow'] = ', '.join(self._allowed_methods())
+        response['Content-Length'] = '0'
+        return response
 
 
-@require_http_methods(['POST', 'OPTIONS'])
-@never_cache
-@api_method
-def store(request, project=None):
+class StoreView(APIView):
     """
     The primary endpoint for storing new events.
 
@@ -117,74 +229,28 @@ def store(request, project=None):
        the user be authenticated, and a project_id be sent in the GET variables.
 
     """
-    logger.debug('Inbound %r request from %r (%s)', request.method, request.META['REMOTE_ADDR'],
-        request.META.get('HTTP_USER_AGENT'))
-    client = '<unknown client>'
+    @never_cache
+    def post(self, request, project, auth, **kwargs):
+        result = plugins.first('has_perm', request.user, 'create_event', project)
+        if result is False:
+            raise APIForbidden('Creation of this event was blocked')
 
-    response = HttpResponse()
+        data = request.raw_post_data
+
+        if not data.startswith('{'):
+            data = decode_and_decompress_data(data)
+        data = safely_load_json_string(data)
 
-    if request.method == 'POST':
         try:
-            auth_vars = extract_auth_vars(request)
-            data = request.raw_post_data
+            validate_data(project, data, auth.client)
+        except InvalidData, e:
+            raise APIError(u'Invalid data: %s (%s)' % (unicode(e), type(e)))
 
-            if auth_vars:
-                server_version = auth_vars.get('sentry_version', '1.0')
-                client = auth_vars.get('sentry_client', request.META.get('HTTP_USER_AGENT'))
-            else:
-                server_version = request.GET.get('version', '1.0')
-                client = request.META.get('HTTP_USER_AGENT', request.GET.get('client'))
+        insert_data_to_database(data)
 
-            if server_version not in ('1.0', '2.0'):
-                raise APIError('Client/server version mismatch: Unsupported version: %r' % server_version)
+        logger.info('New event from project %r (id=%s)', project.slug, data['event_id'])
 
-            if server_version != '1.0' and not client:
-                raise APIError('Client request error: Missing client version identifier.')
-
-            referrer = request.META.get('HTTP_REFERER')
-
-            if auth_vars:
-                # We only require a signature if a referrer was not set
-                # (this is restricted via the CORS headers)
-                project_ = project_from_auth_vars(auth_vars, data,
-                    require_signature=False)
-
-                if not project:
-                    project = project_
-                elif project_ != project:
-                    raise APIError('Project ID mismatch')
-
-            elif request.user.is_authenticated() and is_same_domain(request.build_absolute_uri(), referrer):
-                # authenticated users are simply trusted to provide the right id
-                project_ = project_from_id(request)
-
-                if not project:
-                    project = project_
-                elif project_ != project:
-                    raise APIError('Project ID mismatch')
-
-            else:
-                raise APIUnauthorized()
-
-            if not data.startswith('{'):
-                data = decode_and_decompress_data(data)
-            data = safely_load_json_string(data)
-
-            try:
-                validate_data(project, data, client)
-            except InvalidData, e:
-                raise APIError(u'Invalid data: %s (%s)' % (unicode(e), type(e)))
-
-            insert_data_to_database(data)
-        except APIError, error:
-            logger.info('Client %r raised API error: %s', client, error, extra={
-                'request': request,
-            }, exc_info=True)
-            response = HttpResponse(unicode(error.msg), status=error.http_status)
-        else:
-            logger.info('New event from client %r (id=%s)', client, data['event_id'])
-
-    return response
+        return HttpResponse()
 
 
 @csrf_exempt
@@ -198,33 +264,20 @@ def notification(request, project):
 @has_access
 @never_cache
 def poll(request, project):
-    from sentry.templatetags.sentry_plugins import handle_before_events
-
     offset = 0
     limit = settings.MESSAGES_PER_PAGE
 
-    view_id = request.GET.get('view_id')
-    if view_id:
-        try:
-            view = View.objects.get_from_cache(pk=view_id)
-        except View.DoesNotExist:
-            return HttpResponseBadRequest()
-    else:
-        view = None
-
     response = _get_group_list(
         request=request,
         project=project,
-        view=view,
     )
 
     event_list = response['event_list']
     event_list = list(event_list[offset:limit])
-    handle_before_events(request, event_list)
 
-    data = transform_groups(request, event_list)
+    data = to_json(event_list, request)
 
-    response = HttpResponse(json.dumps(data))
+    response = HttpResponse(data)
     response['Content-Type'] = 'application/json'
     return response
 
@@ -345,19 +398,9 @@ def bookmark(request, project):
 @has_access(MEMBER_USER)
 @never_cache
 def clear(request, project):
-    view_id = request.GET.get('view_id')
-    if view_id:
-        try:
-            view = View.objects.get_from_cache(pk=view_id)
-        except View.DoesNotExist:
-            return HttpResponseBadRequest()
-    else:
-        view = None
-
     response = _get_group_list(
         request=request,
         project=project,
-        view=view,
     )
 
     event_list = response['event_list']
@@ -416,7 +459,7 @@ def get_group_trends(request, project=None):
     )
 
     if has_trending():
-        group_list = list(Group.objects.get_accelerated(base_qs, minutes=(
+        group_list = list(Group.objects.get_accelerated(project_dict.keys(), base_qs, minutes=(
             minutes
         ))[:limit])
     else:
@@ -430,9 +473,9 @@ def get_group_trends(request, project=None):
     for group in group_list:
         group._project_cache = project_dict.get(group.project_id)
 
-    data = transform_groups(request, group_list, template='sentry/partial/_group_small.html')
+    data = to_json(group_list, request)
 
-    response = HttpResponse(json.dumps(data))
+    response = HttpResponse(data)
     response['Content-Type'] = 'application/json'
 
     return response
@@ -453,16 +496,82 @@ def get_new_groups(request, project=None):
     cutoff = datetime.timedelta(minutes=minutes)
     cutoff_dt = timezone.now() - cutoff
 
-    group_list = Group.objects.filter(
+    group_list = list(Group.objects.filter(
         project__in=project_dict.keys(),
         status=0,
         active_at__gte=cutoff_dt,
-    ).order_by('-score')[:limit]
+    ).order_by('-score')[:limit])
 
     for group in group_list:
         group._project_cache = project_dict.get(group.project_id)
 
-    data = transform_groups(request, group_list, template='sentry/partial/_group_small.html')
+    data = to_json(group_list, request)
+
+    response = HttpResponse(data)
+    response['Content-Type'] = 'application/json'
+
+    return response
+
+
+@never_cache
+@csrf_exempt
+@has_access
+def get_resolved_groups(request, project=None):
+    minutes = int(request.REQUEST.get('minutes', 15))
+    limit = min(100, int(request.REQUEST.get('limit', 10)))
+
+    if project:
+        project_list = [project]
+    else:
+        project_list = get_project_list(request.user).values()
+
+    cutoff = datetime.timedelta(minutes=minutes)
+    cutoff_dt = timezone.now() - cutoff
+
+    group_list = Group.objects.filter(
+        project__in=project_list,
+        status=1,
+        resolved_at__gte=cutoff_dt,
+    ).select_related('project').order_by('-score')[:limit]
+
+    data = to_json(group_list, request)
+
+    response = HttpResponse(json.dumps(data))
+    response['Content-Type'] = 'application/json'
+
+    return response
+
+
+@never_cache
+@csrf_exempt
+@has_access
+def get_stats(request, project=None):
+    minutes = int(request.REQUEST.get('minutes', 15))
+
+    if project:
+        project_list = [project]
+    else:
+        project_list = get_project_list(request.user).values()
+
+    cutoff = datetime.timedelta(minutes=minutes)
+    cutoff_dt = timezone.now() - cutoff
+
+    num_events = ProjectCountByMinute.objects.filter(
+        project__in=project_list,
+        date__gte=cutoff_dt,
+    ).aggregate(t=Sum('times_seen'))['t'] or 0
+
+    # XXX: This is too slow if large amounts of groups are resolved
+    num_resolved = Group.objects.filter(
+        project__in=project_list,
+        status=1,
+        resolved_at__gte=cutoff_dt,
+    ).aggregate(t=Sum('times_seen'))['t'] or 0
+
+    data = {
+        'events': num_events,
+        'resolved': num_resolved,
+    }
 
     response = HttpResponse(json.dumps(data))
     response['Content-Type'] = 'application/json'
@@ -490,3 +599,25 @@ def search_tags(request, project):
     response['Content-Type'] = 'application/json'
 
     return response
+
+
+def crossdomain_xml_index(request):
+    response = HttpResponse("""<cross-domain-policy>
+        <site-control permitted-cross-domain-policies="all"></site-control>
+    </cross-domain-policy>""")
+    response['Content-Type'] = 'application/xml'
+    return response
+
+
+@has_access
+def crossdomain_xml(request, project):
+    origin_list = get_origins(project)
+    if origin_list == '*':
+        origin_list = [origin_list]
+
+    response = render_to_response('sentry/crossdomain.xml', {
+        'origin_list': origin_list
+    }, request)
+    response['Content-Type'] = 'application/xml'
+
+    return response
