@@ -24,7 +24,7 @@ class ReplayForm(forms.Form):
         if not value:
             return
 
-        return dict(line.split(': ') for line in value.split('\n'))
+        return dict(line.split(': ') for line in value.splitlines())
 
 
 class BaseUserForm(forms.ModelForm):
@@ -54,3 +54,7 @@ class RemoveUserForm(forms.Form):
         ('1', _('Disable the account.')),
         ('2', _('Permanently remove the user and their data.')),
     ), widget=forms.RadioSelect(renderer=RadioFieldRenderer))
+
+
+class TestEmailForm(forms.Form):
+    pass
