@@ -8,7 +8,7 @@ sentry.web.forms.teams
 from django import forms
 
 from sentry.models import Team, TeamMember, PendingTeamMember
-from sentry.web.forms.fields import UserField
+from sentry.web.forms.fields import UserField, get_team_choices
 from django.utils.translation import ugettext_lazy as _
 
 
@@ -17,23 +17,18 @@ class RemoveTeamForm(forms.Form):
 
 
 class NewTeamForm(forms.ModelForm):
-    name = forms.CharField(max_length=200, widget=forms.TextInput(attrs={'placeholder': _('e.g. My Team Name')}))
-    slug = forms.SlugField(help_text=_('A slug is a URL-safe word and must be unique across all teams.'),
-        widget=forms.TextInput(attrs={'placeholder': _('e.g. my-team-name')}))
+    name = forms.CharField(label=_('Team Name'), max_length=200, widget=forms.TextInput(attrs={'placeholder': _('My Team Name')}))
 
     class Meta:
-        fields = ('name', 'slug')
+        fields = ('name',)
         model = Team
 
 
-class NewTeamAdminForm(forms.ModelForm):
-    name = forms.CharField(max_length=200, widget=forms.TextInput(attrs={'placeholder': _('e.g. My Team Name')}))
-    slug = forms.SlugField(help_text=_('A slug is a URL-safe word and must be unique across all teams.'),
-        widget=forms.TextInput(attrs={'placeholder': _('e.g. my-team-name')}))
+class NewTeamAdminForm(NewTeamForm):
     owner = UserField(required=False)
 
     class Meta:
-        fields = ('name', 'slug', 'owner')
+        fields = ('name', 'owner')
         model = Team
 
 
@@ -52,19 +47,18 @@ class EditTeamAdminForm(EditTeamForm):
 
 
 class SelectTeamForm(forms.Form):
-    team = forms.ChoiceField(choices=())
+    team = forms.TypedChoiceField(choices=(), coerce=int)
 
     def __init__(self, team_list, data, *args, **kwargs):
         super(SelectTeamForm, self).__init__(data=data, *args, **kwargs)
-        self.team_list = dict((str(t.pk), t) for t in team_list.itervalues())
-        self.fields['team'].choices = [c for c in sorted(self.team_list.iteritems(), key=lambda x: x[1].name)]
-        self.fields['team'].choices.insert(0, ('', '-' * 8))
+        self.team_list = dict((t.pk, t) for t in team_list.itervalues())
+        self.fields['team'].choices = get_team_choices(self.team_list)
         self.fields['team'].widget.choices = self.fields['team'].choices
 
     def clean_team(self):
         value = self.cleaned_data.get('team')
-        if not value:
-            return value
+        if not value or value == -1:
+            return None
         return self.team_list.get(value)
 
 
@@ -73,8 +67,8 @@ class BaseTeamMemberForm(forms.ModelForm):
         fields = ('type',)
         model = TeamMember
 
-    def __init__(self, project, *args, **kwargs):
-        self.project = project
+    def __init__(self, team, *args, **kwargs):
+        self.team = team
         super(BaseTeamMemberForm, self).__init__(*args, **kwargs)
 
 
@@ -91,10 +85,10 @@ class InviteTeamMemberForm(BaseTeamMemberForm):
         if not value:
             return None
 
-        if self.project.team.member_set.filter(user__email__iexact=value).exists():
+        if self.team.member_set.filter(user__email__iexact=value).exists():
             raise forms.ValidationError(_('There is already a member with this email address'))
 
-        if self.project.team.pending_member_set.filter(email__iexact=value).exists():
+        if self.team.pending_member_set.filter(email__iexact=value).exists():
             raise forms.ValidationError(_('There is already a pending invite for this user'))
 
         return value
@@ -112,7 +106,11 @@ class NewTeamMemberForm(BaseTeamMemberForm):
         if not value:
             return None
 
-        if self.project.member_set.filter(user=value).exists():
+        if self.team.member_set.filter(user=value).exists():
             raise forms.ValidationError(_('User is already a member of this team'))
 
         return value
+
+
+class AcceptInviteForm(forms.Form):
+    pass
