@@ -5,51 +5,83 @@ sentry.web.frontend.accounts
 :copyright: (c) 2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
-from crispy_forms.helper import FormHelper
 from django.conf import settings as dj_settings
 from django.contrib import messages
+from django.contrib.auth import login as login_user
 from django.core.context_processors import csrf
 from django.core.urlresolvers import reverse
+from django.db import transaction
 from django.http import HttpResponseRedirect
+from django.views.decorators.cache import never_cache
 from django.views.decorators.csrf import csrf_protect
 
 from sentry.models import UserOption
 from sentry.plugins import plugins
 from sentry.web.decorators import login_required
 from sentry.web.forms.accounts import AccountSettingsForm, NotificationSettingsForm, \
-  AppearanceSettingsForm
+  AppearanceSettingsForm, RegistrationForm
 from sentry.web.helpers import render_to_response
 from sentry.utils.auth import get_auth_providers
 from sentry.utils.safe import safe_execute
 
 
 @csrf_protect
+@never_cache
 def login(request):
-    from django.contrib.auth import login as login_
     from django.contrib.auth.forms import AuthenticationForm
+    from sentry.conf import settings
 
     if request.user.is_authenticated():
         return login_redirect(request)
 
     form = AuthenticationForm(request, request.POST or None)
     if form.is_valid():
-        login_(request, form.get_user())
+        login_user(request, form.get_user())
         return login_redirect(request)
 
     request.session.set_test_cookie()
 
-    AUTH_PROVIDERS = get_auth_providers()
-
     context = csrf(request)
     context.update({
         'form': form,
         'next': request.session.get('_next'),
-        'AUTH_PROVIDERS': AUTH_PROVIDERS,
+        'CAN_REGISTER': settings.ALLOW_REGISTRATION or request.session.get('can_register'),
+        'AUTH_PROVIDERS': get_auth_providers(),
         'SOCIAL_AUTH_CREATE_USERS': dj_settings.SOCIAL_AUTH_CREATE_USERS,
     })
     return render_to_response('sentry/login.html', context, request)
 
 
+@csrf_protect
+@never_cache
+@transaction.commit_on_success
+def register(request):
+    from sentry.conf import settings
+
+    if not (settings.ALLOW_REGISTRATION or request.session.get('can_register')):
+        return HttpResponseRedirect(reverse('sentry'))
+
+    form = RegistrationForm(request.POST or None)
+    if form.is_valid():
+        user = form.save()
+
+        # can_register should only allow a single registration
+        request.session.pop('can_register', None)
+
+        # HACK: grab whatever the first backend is and assume it works
+        user.backend = dj_settings.AUTHENTICATION_BACKENDS[0]
+
+        login_user(request, user)
+
+        return login_redirect(request)
+
+    return render_to_response('sentry/register.html', {
+        'form': form,
+        'AUTH_PROVIDERS': get_auth_providers(),
+        'SOCIAL_AUTH_CREATE_USERS': dj_settings.SOCIAL_AUTH_CREATE_USERS,
+    }, request)
+
+
 @login_required
 def login_redirect(request):
     default = reverse('sentry')
@@ -61,6 +93,7 @@ def login_redirect(request):
     return HttpResponseRedirect(login_url)
 
 
+@never_cache
 def logout(request):
     from django.contrib.auth import logout
 
@@ -70,7 +103,9 @@ def logout(request):
 
 
 @csrf_protect
+@never_cache
 @login_required
+@transaction.commit_on_success
 def settings(request):
     form = AccountSettingsForm(request.user, request.POST or None, initial={
         'email': request.user.email,
@@ -90,13 +125,15 @@ def settings(request):
 
 
 @csrf_protect
+@never_cache
 @login_required
+@transaction.commit_on_success
 def appearance_settings(request):
     options = UserOption.objects.get_all_values(user=request.user, project=None)
 
     form = AppearanceSettingsForm(request.user, request.POST or None, initial={
         'language': options.get('language') or request.LANGUAGE_CODE,
-        'stacktrace_order': options.get('stacktrace_order'),
+        'stacktrace_order': int(options.get('stacktrace_order', -1) or -1),
     })
     if form.is_valid():
         form.save()
@@ -112,7 +149,9 @@ def appearance_settings(request):
 
 
 @csrf_protect
+@never_cache
 @login_required
+@transaction.commit_on_success
 def notification_settings(request):
     forms = []
     for plugin in plugins.all():
@@ -120,20 +159,16 @@ def notification_settings(request):
             form = safe_execute(form, plugin, request.user, request.POST or None)
             if not form:
                 continue
-            helper = FormHelper()
-            helper.form_tag = False
-            forms.append((form, helper))
+            forms.append(form)
 
     # Ensure our form comes first
-    helper = FormHelper()
-    helper.form_tag = False
     forms = [
-        (NotificationSettingsForm(request.user, request.POST or None), helper),
+        NotificationSettingsForm(request.user, request.POST or None),
     ] + forms
 
     if request.POST:
-        if all(f.is_valid() for f, h in forms):
-            for form, helper in forms:
+        if all(f.is_valid() for f in forms):
+            for form in forms:
                 form.save()
             messages.add_message(request, messages.SUCCESS, 'Your settings were saved.')
             return HttpResponseRedirect(request.path)
@@ -147,6 +182,7 @@ def notification_settings(request):
 
 
 @csrf_protect
+@never_cache
 @login_required
 def list_identities(request):
     from social_auth.models import UserSocialAuth
