@@ -34,21 +34,12 @@ init_all_applications()
 urlpatterns = patterns('',
     url(r'^_static/(?P<module>[^/]+)/(?P<path>.*)$', generic.static_media, name='sentry-media'),
 
-    # Legacy API
-    url(r'^store/$', api.store),
-
-    # Legacy redirects
-
-    url(r'^group/(?P<group_id>\d+)$', groups.group),
-    url(r'^group/(?P<group_id>\d+)/messages$', groups.group_event_list),
-    url(r'^group/(?P<group_id>\d+)/messages/(?P<event_id>\d+)$', groups.group_event_details),
-    url(r'^group/(?P<group_id>\d+)/actions/(?P<slug>[\w_-]+)$', groups.group_plugin_action),
-
     # Account
 
     url(r'^login/$', accounts.login, name='sentry-login'),
     url(r'^login-redirect/$', accounts.login_redirect, name='sentry-login-redirect'),
     url(r'^logout/$', accounts.logout, name='sentry-logout'),
+    url(r'^register/$', accounts.register, name='sentry-register'),
     url(r'^account/settings/$', accounts.settings, name='sentry-account-settings'),
     url(r'^account/settings/appearance/$', accounts.appearance_settings, name='sentry-account-settings-appearance'),
     url(r'^account/settings/identities/$', accounts.list_identities, name='sentry-account-settings-identities'),
@@ -86,6 +77,8 @@ urlpatterns = patterns('',
     url(r'^account/projects/new/$', projects.new_project, name='sentry-new-project'),
     url(r'^account/projects/(?P<project_id>[\w_-]+)/edit/$', projects.manage_project,
         name='sentry-manage-project'),
+    url(r'^account/projects/(?P<project_id>[\w_-]+)/team/$', projects.manage_project_team,
+        name='sentry-manage-project-team'),
     url(r'^account/projects/(?P<project_id>[\w_-]+)/tags/$', projects.manage_project_tags,
         name='sentry-manage-project-tags'),
     url(r'^account/projects/(?P<project_id>[\w_-]+)/docs/$', projects.client_help,
@@ -108,9 +101,10 @@ urlpatterns = patterns('',
     # Global
 
     url(r'^$', generic.dashboard, name='sentry'),
+    url(r'^wall/$', generic.wall_display, name='sentry-wall'),
     url(r'^manage/status/$', admin.status_env, name='sentry-admin-status'),
     url(r'^manage/status/packages/$', admin.status_packages, name='sentry-admin-packages-status'),
-    url(r'^manage/status/queue/$', admin.status_queue, name='sentry-admin-queue-status'),
+    url(r'^manage/status/mail/$', admin.status_mail, name='sentry-admin-mail-status'),
     url(r'^manage/stats/$', admin.stats, name='sentry-admin-stats'),
 
     # Admin - Projects
@@ -127,10 +121,11 @@ urlpatterns = patterns('',
     url(r'^manage/plugins/(?P<slug>[\w_-]+)/$', admin.configure_plugin, name='sentry-admin-configure-plugin'),
 
     # API / JS
-
-    url(r'^api/store/$', api.store, name='sentry-api-store'),
+    url(r'^crossdomain\.xml$', api.crossdomain_xml_index, name='sentry-api-crossdomain-xml-index'),
+    url(r'^api/store/$', api.StoreView.as_view(), name='sentry-api-store'),
     url(r'^api/notification/$', api.notification, name='sentry-api-notification'),
-    url(r'^api/(?P<project_id>[\w_-]+)/store/$', api.store, name='sentry-api-store'),
+    url(r'^api/(?P<project_id>[\w_-]+)/crossdomain\.xml$', api.crossdomain_xml, name='sentry-api-crossdomain-xml'),
+    url(r'^api/(?P<project_id>[\w_-]+)/store/$', api.StoreView.as_view(), name='sentry-api-store'),
     url(r'^api/(?P<project_id>[\w_-]+)/poll/$', api.poll, name='sentry-api-poll'),
     url(r'^api/(?P<project_id>[\w_-]+)/resolve/$', api.resolve, name='sentry-api-resolve'),
     url(r'^api/(?P<project_id>[\w_-]+)/bookmark/$', api.bookmark, name='sentry-api-bookmark'),
@@ -139,8 +134,10 @@ urlpatterns = patterns('',
     url(r'^api/(?P<project_id>[\w_-]+)/group/(?P<group_id>[\w_-]+)/remove/$', api.remove_group, name='sentry-api-remove-group'),
     url(r'^api/(?:(?P<project_id>[\w_-]+)/)?groups/trends/$', api.get_group_trends, name='sentry-api-groups-trends'),
     url(r'^api/(?:(?P<project_id>[\w_-]+)/)?groups/newest/$', api.get_new_groups, name='sentry-api-groups-new'),
+    url(r'^api/(?:(?P<project_id>[\w_-]+)/)?groups/resolved/$', api.get_resolved_groups, name='sentry-api-groups-resolved'),
     url(r'^api/(?P<project_id>[\w_-]+)/group/(?P<group_id>[\w_-]+)/set/public/$', api.make_group_public, name='sentry-api-set-group-public'),
     url(r'^api/(?P<project_id>[\w_-]+)/group/(?P<group_id>[\w_-]+)/set/private/$', api.make_group_private, name='sentry-api-set-group-private'),
+    url(r'^api/(?:(?P<project_id>[\w_-]+)/)?stats/$', api.get_stats, name='sentry-api-stats'),
     url(r'^api/(?P<project_id>[\w_-]+)/tags/search/$', api.search_tags, name='sentry-api-search-tags'),
 
     # Project specific
@@ -158,7 +155,6 @@ urlpatterns = patterns('',
 
     url(r'^(?P<project_id>[\w_-]+)/search/$', groups.search, name='sentry-search'),
 
-    url(r'^(?P<project_id>[\w_-]+)/view/(?P<view_id>\d+)/$', groups.group_list, name='sentry'),
     url(r'^(?P<project_id>[\w_-]+)/$', groups.group_list, name='sentry'),
 
     url(r'', include('social_auth.urls')),
